pub enum HttpConversionError {
MissingFastcgiParam {
name: &'static str,
},
InvalidHttpMethod(InvalidMethod),
InvalidHttpUri(InvalidUri),
InvalidHttpHeaderName(InvalidHeaderName),
InvalidHttpHeaderValue(InvalidHeaderValue),
InvalidHttpStatusCode(InvalidStatusCode),
InvalidHttpMessage(Error),
MalformedHttpResponse {
message: &'static str,
},
}Available on crate feature
http only.Expand description
Error types that can occur while converting between FastCGI and HTTP types.
Variants
MissingFastcgiParam
Required FastCGI param is missing during HTTP conversion.
InvalidHttpMethod(InvalidMethod)
Invalid HTTP method during conversion.
InvalidHttpUri(InvalidUri)
Invalid HTTP URI during conversion.
InvalidHttpHeaderName(InvalidHeaderName)
Invalid HTTP header name during conversion.
InvalidHttpHeaderValue(InvalidHeaderValue)
Invalid HTTP header value during conversion.
InvalidHttpStatusCode(InvalidStatusCode)
Invalid HTTP status code during conversion.
InvalidHttpMessage(Error)
Invalid HTTP message constructed by builder.
MalformedHttpResponse
CGI response payload could not be parsed into headers and body.