Module io

Module io 

Runtime-neutral async I/O facade used by the FastCGI client.

Structs

Cursor
A Cursor wraps an in-memory buffer and provides it with a AsyncSeek implementation.
Empty
Reader for the empty() function.
Error
The error type for I/O operations of the Read, Write, Seek, and associated traits.
TokioCompatruntime-tokio
A compatibility layer that allows conversion between the tokio::io and futures-io AsyncRead and AsyncWrite traits.

Enums

ErrorKind
A list specifying general categories of I/O error.

Traits

AsyncRead
Read bytes asynchronously.
AsyncReadExt
An extension trait which adds utility methods to AsyncRead types.
AsyncWrite
Write bytes asynchronously.
AsyncWriteExt
An extension trait which adds utility methods to AsyncWrite types.
TokioAsyncReadCompatExtruntime-tokio
Extension trait that allows converting a type implementing tokio::io::AsyncRead to implement futures_io::AsyncRead.
TokioAsyncWriteCompatExtruntime-tokio
Extension trait that allows converting a type implementing tokio::io::AsyncWrite to implement futures_io::AsyncWrite.

Functions

empty
Constructs a new handle to an empty reader.

Type Aliases

Result
A specialized Result type for I/O operations.